
Available Contests
==================

The table shows all available contests with the last date the contest definition was updated.

The *Year* column shows the year the contest definition is targeted to. 
If it does not show the current year you should check for a program update.

The *Internal ID* is the ID which is imported or exported in ADIF format. 

The *Exch format* is the format you must use to type in the received exchange. 
If a separator is you can also use a blank or underscore instead of a comma.
The sent exchange is handled automatically.

| Contest name | Internal ID | Year | Updated | Exch format |
|--------------|-------------|------|---------|-------------|
| DARC UKW-Wettbewerb | DARC-UKW | ***2025*** | 2025-04-07 | Number,Locator |
| DARC UKW Frühlingswettbewerb | DARC-UKW-FRUEHLING | ***2025*** | 2025-04-07 | Number,Locator |
| DARC UKW-Sommer-Fieldday | DARC-UKW-SOMMERFD | ***2025*** | 2025-08-02 | Number,Locator |
| DARC-Ostercontest | DARC-KW-OSTERN | ***2025*** | 2025-04-13 | DOK |
| RLP Aktivitätswoche | RL-PFALZ-AW | ***2025*** | 2025-01-05 | DOK |
| RLP Aktivitätsabend UKW | RL-PFALZ-AB.UKW | ***2025*** | 2025-05-08 | DOK,Locator |
| RLP Aktivitätsabend KW | RL-PFALZ-AB.KW | ***2025*** | 2025-05-08 | DOK |
| K32 FM-Kurzaktivität | K32-KURZ-UKW | ***2025*** | 2025-05-05 | DOK,Class |
| L33 Einsteiger-Contest | L33-EINSTEIGER | ***2025*** | 2025-04-06 | Number,Locator |
| IARU HF World Championship | IARU-HF | ***2025*** | 2025-07-08 | ITU-Zone |
| KW-Contest | KW-UNIVERSAL | ***2025*** | 2025-01-01 | Number |
| UKW-Contest | UKW-UNIVERSAL | ***2025*** | 2025-01-01 | Number,Locator |
